@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes;
 {
-    $Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.2';
+  $Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes::VERSION = '0.0.3';
 }
 
 # ABSTRACT: Format Changelogs using CPAN::Changes
@@ -11,6 +11,22 @@ use CPAN::Changes::Release;
 
 extends 'Dist::Zilla::Plugin::ChangelogFromGit';
 
+has group_by_author => ( is => 'ro', isa => 'Bool', default => 0);
+
+has show_author_email => ( is => 'ro', isa => 'Bool', default => 0);
+
+has _git_tag => (
+    is      => 'ro',
+    lazy    => 1,
+    isa     => 'Maybe[Dist::Zilla::Plugin::Git::Tag]',
+    default => sub {
+        foreach (@{shift->zilla->plugins}) {
+            return $_ if ref eq 'Dist::Zilla::Plugin::Git::Tag';
+        }
+        return;
+    },
+);
+
 sub render_changelog {
     my ($self) = @_;
 
@@ -20,8 +36,12 @@ sub render_changelog {
         next if $release->has_no_changes;    # no empties
 
         my $version = $release->version;
-        if ( $version eq 'HEAD' ) {
-            $version = $self->zilla->version;
+        if ($version eq 'HEAD') {
+            if ($self->_git_tag) {
+                $version = $self->_git_tag->tag;
+            } else {
+                $version = $self->zilla->version;
+            }
         }
 
         my $cpan_release = CPAN::Changes::Release->new(
@@ -30,19 +50,22 @@ sub render_changelog {
         );
 
         foreach my $change ( @{ $release->changes } ) {
-            next if ( $change->description =~ /^\s/ );    # no empties
-            my $group = $change->author_name;
+            next if $change->description =~ /^\s+$/; # does git allow empty messages?
+            
+            my $author = $change->author_name;
 
-            # sometimes author_name contains the "Full Name <email@address.com>"
-            # sometimes not, so do a lazy check
-            if ( $change->author_name !~ m/@/ ) {
-                $group .= ' <' . $change->author_email . '>';
+            if ($self->show_author_email) {
+                $author .= ' <' . $change->author_email . '>';
             }
+            my $desc = $change->description;
+            chomp $desc;
 
-            # XXX: do we want the change_id?
-            # $group .= ' ' .  $change->change_id;
-
-            $cpan_release->add_changes( { group => $group }, $change->description, );
+            if ($self->group_by_author) {
+                my $group = $author;
+                $cpan_release->add_changes( { group => $group }, $desc );
+            } else {
+                $cpan_release->add_changes( $desc . " [$author]" );
+            }
         }
 
         $cpan_changes->add_release($cpan_release);
@@ -65,7 +88,27 @@ Dist::Zilla::Plugin::ChangelogFromGit::CPAN::Changes - Format Changelogs using C
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
+
+=head1 SYNOPSIS
+
+ [ChangelogFromGit::CPAN::Changes]
+ ; All options from [ChangelogFromGit] plus
+ group_by_author = 1 ; default 0
+ show_author_email = 1 ; default 0
+
+=head1 ATTRIBUTES
+
+=head2 group_by_author
+
+Whether to group commit messages by their author. This is the only way previous
+versions did it. Defaults to no, and [ Anne Author ] is appended to the commit
+message.
+
+=head2 show_author_email
+
+Author email is probably just noise for most people, but turn this on if you
+want to show it [ Anne Author <anne@author.com> ]
 
 =head1 SEE ALSO
 
@@ -87,7 +130,7 @@ Ioan Rogers <ioanr@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ioan Rogers.
+This software is copyright (c) 2013 by Ioan Rogers.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
